RadarSwap = {}
RadarSwap.default_vals = {} --save settings that would be used if plugin not installed
RadarSwap.version = '1.0'

--## Choco ##--

RadarSwap.vars = dofile'vars.lua'

local radar_sets = {
	trident = {"plugins/RadarSwap/img/trident_front.png", "plugins/RadarSwap/img/trident_rear.png"},
	vulture = {"plugins/RadarSwap/img/vulture_front.png", "plugins/RadarSwap/img/vulture_rear.png"},
	
	--generic sets
	legacy = {"plugins/RadarSwap/img/legacy.png", "plugins/RadarSwap/img/legacy.png"},
	sphere = {"plugins/RadarSwap/img/sphere.png", "plugins/RadarSwap/img/sphere.png"},
	grid = {"plugins/RadarSwap/img/grid.png", "plugins/RadarSwap/img/grid.png"},
}

--genereates text string of all available radar sets
local function get_set_names()
	local ret = ""
	for set_name,_ in pairs(radar_sets) do
		ret = ret..set_name..", "
	end
	return ret.."default"
end

function RadarSwap:PLAYER_ENTERED_GAME(event, data)
	RegisterEvent(RadarSwap, "HUD_SHOW")
end

--initialization when logging in
function RadarSwap:HUD_SHOW(event, data)
	local radar_left = HUD.radarlayer[2][1][2] --convenience
	local radar_right = HUD.radarlayer[2][3][2] --convenience
	
	if not next(RadarSwap.default_vals) then --defaults not yet saved
		RadarSwap.default_vals.image_left = radar_left.IMAGE
		RadarSwap.default_vals.image_right = radar_right.IMAGE
		
		RadarSwap.default_vals.size_left = radar_left.SIZE
		RadarSwap.default_vals.size_right = radar_right.SIZE
		
		RadarSwap.default_vals.blipscale_left = radar_left.BLIPSCALE
		RadarSwap.default_vals.blipscale_right = radar_right.BLIPSCALE
	end
	
	local all_vars = RadarSwap.vars.GetAll()
	
	RadarSwap:set{all_vars.RadarSet, "false"}
	RadarSwap:size{all_vars.Size, "false"}
	RadarSwap:blipscale{all_vars.BlipScale, "false"}
	
	iup.Refresh(HUD.dlg)
	
	UnregisterEvent(RadarSwap, "HUD_SHOW") --only want to trigger once per login
end

function RadarSwap:set(args)
	local set_name = args[1] and args[1]:lower()
	local is_save = args[2] and tostring(args[2]):lower()
	local radar_set = set_name and radar_sets[set_name]
	
	local radar_left = HUD.radarlayer[2][1][2] --convenience
	local radar_right = HUD.radarlayer[2][3][2] --convenience
	
	if radar_set then
		radar_left.IMAGE = radar_set[1]
		radar_right.IMAGE = radar_set[2]
	elseif set_name == "default" then --use game default
		radar_left.IMAGE = RadarSwap.default_vals.image_left
		radar_right.IMAGE = RadarSwap.default_vals.image_right
	else print'Invalid radar set name'; return end --TODO better error message
	
	if is_save==nil or is_save=="true" or is_save=="yes" or is_save=="y" or is_save=="1" or is_save=="save" then
		RadarSwap.vars.SaveVars('RadarSet', set_name)
	end
	
	iup.Refresh(HUD.dlg)
end

function RadarSwap:size(args)
	local size = tonumber(args[1])
	local text = args[1] and tostring(args[1]):lower()
	local is_save = args[2] and tostring(args[2]):lower()
	
	local radar_left = HUD.radarlayer[2][1][2] --convenience
	local radar_right = HUD.radarlayer[2][3][2] --convenience
	
	if text == "default" then size = 0 end
	if not size then print'you must specify the radar size (integer)'; return end
	
	size = math.floor(size or 0)
	
	if size == 0 then --use game default
		radar_left.SIZE = RadarSwap.default_vals.size_left
		radar_right.SIZE = RadarSwap.default_vals.size_right
	elseif size < 100 then
		print'size must be greater than 100'; return
	else
		radar_left.SIZE = size.."x"..size
		radar_right.SIZE = radar_left.SIZE
	end
	
	if is_save==nil or is_save=="true" or is_save=="yes" or is_save=="y" or is_save=="1" or is_save=="save" then
		RadarSwap.vars.SaveVars('Size', size)
	end
	
	iup.Refresh(HUD.dlg)
end

function RadarSwap:blipscale(args)
	local scale = tonumber(args[1])
	local text = args[1] and tostring(args[1]):lower()
	local is_save = args[2] and tostring(args[2]):lower()
	
	local radar_left = HUD.radarlayer[2][1][2] --convenience
	local radar_right = HUD.radarlayer[2][3][2] --convenience
	
	if text == "default" then scale = 0 end
	if not scale then print'you must specify a number for the blip scale'; return end
	
	if scale == 0 then --use game default
		radar_left.BLIPSCALE = RadarSwap.default_vals.blipscale_left
		radar_right.BLIPSCALE = RadarSwap.default_vals.blipscale_right
	else
		radar_left.BLIPSCALE = scale
		radar_right.BLIPSCALE = scale
	end
	
	if is_save==nil or is_save=="true" or is_save=="yes" or is_save=="y" or is_save=="1" or is_save=="save" then
		RadarSwap.vars.SaveVars('BlipScale', scale)
	end
	
	iup.Refresh(HUD.dlg)
end

function RadarSwap:defaults(args)
	local is_save = args[1] and tostring(args[1]):lower()
	
	local radar_left = HUD.radarlayer[2][1][2] --convenience
	local radar_right = HUD.radarlayer[2][3][2] --convenience
	
	radar_left.IMAGE = RadarSwap.default_vals.image_left
	radar_right.IMAGE = RadarSwap.default_vals.image_right
	
	radar_left.SIZE = RadarSwap.default_vals.size_left
	radar_right.SIZE = RadarSwap.default_vals.size_right
	
	radar_left.BLIPSCALE = RadarSwap.default_vals.blipscale_left
	radar_right.BLIPSCALE = RadarSwap.default_vals.blipscale_right
	
	if is_save==nil or is_save=="true" or is_save=="yes" or is_save=="y" or is_save=="1" or is_save=="save" then
		RadarSwap.vars.SaveVars('RadarSet', "default")
		RadarSwap.vars.SaveVars('Size', 0)
		RadarSwap.vars.SaveVars('BlipScale', 0)
	end
	
	iup.Refresh(HUD.dlg)
end

local help_text= {
	['help']='\127ffffffRadarSwap v'..RadarSwap.version..'  Available commands are: (for more info use /RadarSwap help \127ffff00COMMAND\127o)'..
		'\n\t/RadarSwap set \127ffff00Name\127o - sets the radar image to the given set name. To see list of available sets, use /RadarSwap help set'..
		'\n\t/RadarSwap size \1270070c0N\127o - sets the size of both radars in pixels'..
		'\n\t/RadarSwap blipscale \1270070c0N\127o - Sets the size of the radar blips. 0.25 to 3 usually works best'..
		'\n\t/RadarSwap defaults - Restores all settings to what they would be without plugin installed',
	['set']='\127ffffff/RadarSwap set \127ffff00Name\127o - sets the radar image to the given set name'..
		'\n\tAvailable radar sets are: '..get_set_names(),
	['size']='\127ffffff/RadarSwap size \1270070c0N\127o - sets the size of both radars in pixels'..
		'\n\tUse \1270070c0N\127o=DEFAULT to restore the default radar size'..
		'\n\tYou can specify a third argument of FALSE to temporarily set the radar size for this session without saving to the config file',
	['blipscale']='\127ffffff/RadarSwap blipscale \1270070c0N\127o - Sets the size of the radar blips. 0.25 to 3 usually works best'..
		'\n\tUse \1270070c0N\127o=DEFAULT to restore the default blip size'..
		'\n\tYou can specify a third argument of FALSE to temporarily set the radar blip size for this session without saving to the config file',
	['defaults']='\127ffffff/RadarSwap defaults - Restores all settings to what they would be without plugin installed'..
		'\n\tYou can specify a second argument of FALSE to temporarily restore defaults for this session without saving to the config file'..
		'\n\te.g. /RadarSwap defaults false',
	['command']='\127ffffffTo get more information about how to use a command, type: /RadarSwap help \127ffff00COMMAND\127o'..
		'\n\tWhere \127ffff00COMMAND\127o is the command you want to get help on (e.g. /RadarSwap help set)',
}

--console help text
function RadarSwap:help(args)
	args = args or {}
	
	print(args[1] and help_text[args[1]:lower()] or help_text.help)
end

local inputs = {set=true, size=true, blipscale=true, defaults=true, help=true}
function RadarSwap:input(args)
	args = args or {}
	local command = args[1] and args[1]:lower()
	if command then table.remove(args, 1) end
	
	if inputs[command] then
		RadarSwap[command](RadarSwap, args)
	else RadarSwap.help(RadarSwap) end
end

RegisterUserCommand('RadarSwap', RadarSwap.input)
RegisterEvent(RadarSwap, "HUD_SHOW")