local vars = {}
local VARS_ID = "RadarSwap" --TAG to save vars in config.ini

--[=[ NOTATION
vars_list.key={
	format = (string), --'Int' or 'String' how to save in config file, case matters!!!
	default = (int or string depending on format), --default setting
	key = (string), --key to write var in config file
	bool = (), -- (optional) if the value is equal to this then treat as true, otherwise false -- don't set to nil or false
} --]=]
local vars_list = {
	RadarSet={
		format = "String",
		default = "trident",
		key = "RadarSet",
	},
	Size={
		format = "Int",
		default = 0, --use game default when zero
		key = "Size",
	},
	BlipScale={
		format = "Int",
		default = 0, --use game default when zero
		key = "BlipScale",
	},
}

--DEBUG --prints debug info for all vars
--options.output = function to use to print output string(s)
function vars.print_vars(options)
	local options = options or {}
	local output = type(options.output)=='function' and options.output or console_print
	
	local function print_func(vars_key)
		if not vars_list[vars_key] then output('Bad Key: '..tostring(vars_key)); return end
		
		output(tostring(vars_key)..":")
		local data = vars_list[vars_key]
		
		for k,v in pairs(data) do
			output("\t"..(k or 'nil')..": "..(v or 'nil'))
		end
	end
	
	if not options.key then
		for vars_key,_ in pairs(vars_list) do print_func(vars_key) end
	else print_func(options.key) end
end

local function read_val(key)
	console_print(key)
	console_print("Read"..(vars_list[key].format or "String"))
	console_print(tostring(gkini["Read"..(vars_list[key].format or "String")]))
	console_print(tostring( vars_list[key].key ))
	console_print(tostring( vars_list[key].default ))
	local val = gkini["Read"..(vars_list[key].format or "String")](VARS_ID, vars_list[key].key, vars_list[key].default)
	if vars_list[key].bool then val = val == vars_list[key].bool end
	
	return val
end

--Returns value for given key from config.ini
function vars.GetVars(key)
	if vars_list[key] then
		return read_val(key)
	else return end
end

--Write given key with value to config.ini
function vars.SaveVars(key, val)
	local function save_val(key, val)
		if val==true then
			val = vars_list[key].bool or (vars_list[key].format=="Int" and 1 or 'true')
		elseif val==false then
			val = vars_list[key].format=="Int" and 0 or 'false'
		end
		
		gkini["Write"..(vars_list[key].format or "String")](VARS_ID, vars_list[key].key, val)
		
		return val
	end
	
	if vars_list[key] and val~=nil then
		return save_val(key, val)
	else return end
end

--Returns table containing all values read from config
function vars.GetAll()
	local all_values = {} --table to return
	
	for key,data in pairs(vars_list) do
		all_values[key] = read_val(key) --can be nil (ignored)
	end
	
	return all_values
end

--Returns default value for given key
function vars.GetDefault(key) return vars_list[key] and vars_list[key].default end

return vars